@@ -18,7 +18,7 @@ try:
 except ImportError:
     opencv = None
 
-from numm.sound import sound2np, np2sound
+from numm.sound import sound2np, np2sound, sound_chunks
 from numm.image import image2np, np2image
-from numm.video import video2np, np2video
+from numm.video import video2np, np2video, video_frames
 from numm.async import Run, run
